==> svm-22.0.0-sources.jar: com/oracle/svm/hosted/NativeImageClassLoaderPostProcessing.java <==
/*
 * Copyright (c) 2021, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package com.oracle.svm.hosted;

/**
 * ServiceLoader interface to allow post-processing tasks that should be performed right after
 * {@link AbstractNativeImageClassLoaderSupport} is created. For example, this is used to apply the
 * native-image classloader options after hosted options are accessible but before
 * {@link com.oracle.svm.hosted.ImageClassLoader#initAllClasses()} gets called.
 */
public interface NativeImageClassLoaderPostProcessing {

    void apply(AbstractNativeImageClassLoaderSupport support);

}

==> svm-22.3.0-sources.jar: com/oracle/svm/hosted/NativeImageClassLoaderPostProcessing.java <==
/*
 * Copyright (c) 2021, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package com.oracle.svm.hosted;

/**
 * ServiceLoader interface to allow post-processing tasks that should be performed right after
 * {@link NativeImageClassLoaderSupport} is created. For example, this is used to apply the
 * native-image classloader options after hosted options are accessible but before
 * {@link com.oracle.svm.hosted.ImageClassLoader#initAllClasses()} gets called.
 */
public interface NativeImageClassLoaderPostProcessing {

    void apply(NativeImageClassLoaderSupport support);

}
